@@ -5,9 +5,22 @@ package Template::Lace::DOM;
 use base 'Mojo::DOM58';
 use Storable ();
 use Scalar::Util;
+use Template::Tiny;
 
 # General Helpers
 
+my $tt = Template::Tiny->new;
+
+sub tt {
+  my ($dom, @proto) = @_;
+  my %vars = ref($proto[0]) eq 'HASH' ? %{$proto[0]} : @proto;
+  my $output = '';
+  my $input = $dom->content;
+  $tt->process( \$input, \%vars, \$output );
+  $dom->content($output);
+  return $dom;
+}
+
 sub ctx {
   my $self = shift;
   local $_ = $self;
@@ -387,6 +400,21 @@ sub class {
   }
 }
 
+sub add_class {
+  my ($self, @proto) = @_;
+  my $current_class = $self->attr('class') ||'';
+  if(ref($proto[0]) eq 'HASH') {
+    my $classes = join ' ', grep { $proto[0]->{$_} } keys %{$proto[0]};
+    return $self->attribute_helper('class', "$current_class $classes");
+  } elsif(ref($proto[0]) eq 'ARRAY') {
+    my $classes = join ' ', @{$proto[0]};
+    return $self->attribute_helper('class', "$current_class $classes");    
+  } else {
+    my $classes = shift @proto;
+    return $self->attribute_helper('class', "$current_class $classes");
+  }
+}
+
 sub boolean_attribute_helper {
   my ($self, $name, $value) = @_;
   $self->attribute_helper($name, 'on') if $value;
@@ -975,6 +1003,22 @@ it for you
 B<NOTE> if you want to set content or attributes on the DOM that ->do is run on
 you can use '.' as the match specification.
 
+=head2 tt
+
+Lets you fill the matching node's content via <Template::Tiny>.  This of course
+violates the 'pure no logic templates' but its here as an escapt hatch should
+you find the transformation are very awkward.  Also its probably the best way
+to fill variable into an inline script.
+
+  my $dom = Template::Lace::DOM->new(
+    qq[<span>Hello [% name%]! It is a [% weather %] day!</span>]);
+
+  $dom->at('span')
+   ->tt(name=>'John',
+     weather=>'great');
+
+  print $dom; # prints '<span>Hello John! It is a great day!</span>'
+
 =head1 ATTRIBUTE HELPERS
 
 The following methods are intended to make setting standard attributes on
@@ -1046,6 +1090,11 @@ If you instead use an arrayref, all the classes are just added.
 
 Useful to reduce some boilerplate.
 
+=head2 add_class
+
+Works just like L</class> except the classes are added to any ones that are already
+there.
+
 =head1 UNIQUE TAG HELPERS
 
 Helpers to access tags that are 'unique', typically only appearing
